@@ -1,5 +1,5 @@
 use std::error::Error;
 
-pub trait EventDecoder<E> {
+pub trait PayloadDecoder<E> {
     fn decode(&mut self, bytes: Vec<u8>) -> Result<E, Box<dyn Error>>;
 }
